@@ -1,7 +1,7 @@
 import urllib.parse
 from salesforce_tools.salesforce import SalesforceAPI
 from enum import Enum
-from bulk_models import JobInfo, JobInfoList, BatchInfo, BatchInfoList, \
+from salesforce_tools.bulk_models import JobInfo, JobInfoList, BatchInfo, BatchInfoList, \
     OperationEnum, ContentTypeEnum, ContentTypeHeaderEnum, JobTypeEnum, JobStateEnum, BulkAPIError, APIError,\
     BulkException
 from typing import Union, Optional, List
